package fr.openium.consentium_ui.ui

import androidx.compose.animation.AnimatedContent
import androidx.compose.animation.slideIn
import androidx.compose.animation.slideOut
import androidx.compose.animation.togetherWith
import androidx.compose.runtime.Composable
import androidx.compose.ui.unit.IntOffset
import fr.openium.consentium_ui.ui.components.ConsentiumUIDetailConsentComponent
import fr.openium.consentium_ui.ui.components.ConsentiumUIErrorComponent
import fr.openium.consentium_ui.ui.components.ConsentiumUIGeneralConsentComponent
import fr.openium.consentium_ui.ui.components.ConsentiumUILoadingComponent
import fr.openium.consentium_ui.ui.components.ConsentiumUIWebview
import fr.openium.consentium_ui.ui.model.ConsentiumPageUI
import fr.openium.consentium_ui.ui.model.DetailConsentUI
import fr.openium.consentium_ui.ui.model.LoadingElement
import fr.openium.consentium_ui.ui.state.ConsentiumUIState

@Composable
internal fun ConsentiumScreen(
    page: ConsentiumPageUI,
    state: ConsentiumUIState,
    loadingElement: LoadingElement,
    onNavigateBack: () -> Unit,
    onAcceptAndClose: (consents: DetailConsentUI) -> Unit,
    onDenyAndClose: (consents: DetailConsentUI) -> Unit,
    onSaveAndCloseDetails: (consents: DetailConsentUI) -> Unit,
    onNavigateToDetails: () -> Unit,
    onClickCookiesPolicies: () -> Unit,
    onClickRetry: () -> Unit,
) {
    when (state) {
        is ConsentiumUIState.Loading -> {
            ConsentiumUILoadingComponent()
        }

        is ConsentiumUIState.Error -> {
            ConsentiumUIErrorComponent(
                errorMessage = state.message,
                onRetry = onClickRetry
            )
        }

        is ConsentiumUIState.Loaded -> {
            AnimatedContent(
                targetState = page,
                transitionSpec = {
                    when (page) {
                        ConsentiumPageUI.GENERAL_CONSENT -> {
                            slideIn(
                                initialOffset = { fullSize -> IntOffset(-fullSize.width, 0) }
                            ).togetherWith(
                                slideOut(
                                    targetOffset = { fullSize -> IntOffset(fullSize.width, 0) }
                                )
                            )
                        }

                        else -> {
                            slideIn(
                                initialOffset = { fullSize -> IntOffset(fullSize.width, 0) }
                            ).togetherWith(
                                slideOut(
                                    targetOffset = { fullSize -> IntOffset(-fullSize.width, 0) }
                                )
                            )
                        }
                    }
                }
            ) { currentPage ->

                when (currentPage) {
                    ConsentiumPageUI.GENERAL_CONSENT -> {
                        ConsentiumUIGeneralConsentComponent(
                            generalConsentUI = state.generalConsentUI,
                            onNavigateToDetails = onNavigateToDetails,
                            onAcceptAndClose = {
                                onAcceptAndClose(state.detailConsentUI)
                            },
                            onDenyAndClose = {
                                onDenyAndClose(state.detailConsentUI)
                            },
                            onClickCookiesPolicies = onClickCookiesPolicies,
                            loadingElement = loadingElement
                        )
                    }

                    ConsentiumPageUI.DETAILS_CONSENT -> {
                        ConsentiumUIDetailConsentComponent(
                            detailConsentUI = state.detailConsentUI,
                            onNavigateBack = onNavigateBack,
                            onSave = {
                                onSaveAndCloseDetails(state.detailConsentUI)
                            },
                            loadingElement = loadingElement
                        )
                    }

                    ConsentiumPageUI.COOKIES_POLICY -> {
                        ConsentiumUIWebview(
                            url = state.detailConsentUI.cookiePolicyUrl
                        )
                    }
                }

            }
        }
    }
}

