package fr.openium.consentium_ui.ui.components.core

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.semantics.contentDescription
import androidx.compose.ui.semantics.semantics
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import fr.openium.consentium_ui.R
import fr.openium.consentium_ui.ui.components.core.toggle.ConsentiumUISwitch
import fr.openium.consentium_ui.ui.components.style.ConsentiumUITheme
import fr.openium.consentium_ui.ui.model.PurposeStatusUI
import fr.openium.consentium_ui.ui.model.PurposeUI
import fr.openium.consentium_ui.ui.utils.toRichHtmlString

@Composable
internal fun PurposeComponent(
    purposeUI: PurposeUI,
) {
    // Properties
    var isChecked by remember { mutableStateOf(purposeUI.choice != PurposeStatusUI.REJECTED) }

    // View
    Column(
        modifier = Modifier.fillMaxWidth(),
    ) {

        Row(
            modifier = Modifier.fillMaxWidth(),
            verticalAlignment = Alignment.CenterVertically,
        ) {
            Text(
                text = purposeUI.title,
                style = ConsentiumUITheme.typography.b3,
                color = ConsentiumUITheme.colors.onSurface,
            )

            Spacer(modifier = Modifier.weight(1f))

            if (purposeUI.isRequired) {
                Text(
                    text = stringResource(id = R.string.require),
                    style = ConsentiumUITheme.typography.b3,
                    color = ConsentiumUITheme.colors.onSurface,
                )
            } else {
                ConsentiumUISwitch(
                    checked = isChecked,
                    onCheckedChange = {
                        isChecked = !isChecked
                        purposeUI.choice = if (isChecked) PurposeStatusUI.ACCEPTED else PurposeStatusUI.REJECTED
                        purposeUI.vendors.forEach { vendorUI ->
                            vendorUI.isAccepted = isChecked
                        }
                    },
                    modifier = Modifier
                        .semantics {
                            contentDescription = purposeUI.title
                        }
                )
            }

            /** To enable in v2
            Spacer(modifier = Modifier.width(10.dp))

            Icon(
            modifier = Modifier.size(24.dp),
            imageVector = Icons.AutoMirrored.Filled.KeyboardArrowRight,
            contentDescription = null,
            tint = ConsentiumUITheme.colors.onSurface,
            )
             **/
        }

        Spacer(modifier = Modifier.height(10.dp))

        Text(
            text = purposeUI.description.toRichHtmlString(),
            style = ConsentiumUITheme.typography.p3,
            color = ConsentiumUITheme.colors.onSurface,
        )
    }
}

@Preview
@Composable
private fun PurposeComponentPreview() {
    PurposeComponent(
        purposeUI = PurposeUI(
            id = "1",
            isRequired = true,
            choice = PurposeStatusUI.ACCEPTED,
            title = "Title",
            description = "Description",
            vendors = emptyList(),
        )
    )
}